@@ -32,24 +32,21 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                              
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)),
-                                                   stringsAsFactors = FALSE)
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
                                  
                                  for(j in seq(along = param$.n.trees))
                                    {
                                      if(modelFit$problemType == "Classification")
                                        {
                                          gbmProb <- predict(modelFit, newdata, type = "response", n.trees = param$.n.trees[j])
-                                         tmp[,j] <- ifelse(gbmProb >= .5, modelFit$obsLevels[1], modelFit$obsLevels[2])
+                                         tmp[[j+1]] <- ifelse(gbmProb >= .5, modelFit$obsLevels[1], modelFit$obsLevels[2])
                                          ## to correspond to gbmClasses definition above
                                        } else {
-                                         tmp[,j]  <- predict(modelFit, newdata, type = "response", n.trees = param$.n.trees[j])
+                                         tmp[[j+1]]  <- predict(modelFit, newdata, type = "response", n.trees = param$.n.trees[j])
                                        }
                                    }
-                                 
-                                 out <- cbind(out, tmp)
-                                 if(modelFit$problemType == "Classification") out <- coerceChar(out)
+                                 out <- if(modelFit$problemType == "Classification") lapply(tmp, as.character) else tmp
                                }
                              out
                            },
@@ -127,12 +124,8 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
 
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param) + 1),
-                                                   stringsAsFactors = FALSE)
-                                 
-                                 ## translate maxdepth to Cp: interpolate points in-between
-                                 tmp[, 1] <- out
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
                                  cpValues <- depth2cp(modelFit$cptable, param$.maxdepth)
                                  
                                  for(j in seq(along = cpValues))
@@ -140,15 +133,15 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                      prunedFit <- prune.rpart(modelFit, cp = cpValues[j])
                                      if(modelFit$problemType == "Classification")
                                        {
-                                         tmp[,j + 1] <- as.character(predict(prunedFit, newdata, type="class"))
+                                         tmp[[j+1]] <- as.character(predict(prunedFit, newdata, type="class"))
                                        } else {
-                                         tmp[,j + 1]  <- predict(prunedFit, newdata, type="vector")
+                                         tmp[[j+1]]  <- predict(prunedFit, newdata, type="vector")
                                        }
                                    }
-                                 if(modelFit$problemType == "Classification") tmp <- coerceChar(tmp)
-                                 out <- tmp
+                                 out <- if(modelFit$problemType == "Classification") lapply(tmp, as.character) else tmp
                                }
                              out
+                             
                            },
                            
                            lvq =
@@ -168,61 +161,53 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                  out <- predict(modelFit, newdata, type="class")
                                  
                                } else as.vector(predict(modelFit, newdata, ncomp = max(modelFit$ncomp)))
-                             
-                             
+
                              if(!is.null(param))
                                {
+                                 ## We'll merge the first set of predictions below
+                                 tmp <- vector(mode = "list", length = nrow(param))
+                                 
                                  if(modelFit$problemType == "Classification")
                                    {
-                                     tmp <- if(length(param$.ncomp) > 1) predict(modelFit, newdata, ncomp = param$.ncomp)
-                                     else data.frame(pred = predict(modelFit, newdata, ncomp = param$.ncomp))
-                                     tmp <- as.data.frame(lapply(tmp, as.character), stringsAsFactors = FALSE)
-                                     ## if we are in this block, ncomp the prediction should be a vector
-                                     out <- cbind(as.character(out), tmp)
+                                     if(length(param$.ncomp) > 1)
+                                       {
+                                         tmp <- as.list(predict(modelFit, newdata, ncomp = param$.ncomp))
+                                       } else tmp <- list( predict(modelFit, newdata, ncomp = param$.ncomp))
+
                                    } else {
-                                     tmp <- if(length(param$.ncomp) > 1) predict(modelFit, newdata, ncomp = param$.ncomp)[,1,]
-                                     else data.frame(pred = predict(modelFit, newdata, ncomp = param$.ncomp))
-                                     out <- cbind(out, tmp)
+                                     tmp <- as.list(
+                                                    as.data.frame(
+                                                                  apply(predict(modelFit, newdata, ncomp = param$.ncomp),
+                                                                        3,
+                                                                        function(x) list(x))))
                                    }
 
-                                 if(modelFit$problemType == "Classification") out <- coerceChar(out)
-                                 out <- as.data.frame(out)
+                                 out <- c(list(out), tmp)
+                                 if(modelFit$problemType == "Classification") out <- lapply(out, as.character)
                                }
                              out
                            },
-                           
-                           PLS =,
-                           {
-                             library(pls)
-                             if(modelFit$problemType == "Classification")
-                               {
-                                 out <- as.character(predict(modelFit, as.matrix(newdata),  ncomp = modelFit$tuneValue$.ncomp))
-                               } else {
-                                 out <- as.vector(predict(modelFit, as.matrix(newdata), ncomp = modelFit$tuneValue$.ncomp))
-                               }
-                             out
-                           },
-                           
+
                            pam =
                            {
                              library(pamr)
                              
-                             out <- as.character(pamr.predict(modelFit, t(newdata),
+                             out <- as.character(
+                                                 pamr.predict(modelFit,
+                                                              t(newdata),
                                                               threshold = modelFit$tuneValue$.threshold))
                              
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param) + 1),
-                                                   stringsAsFactors = FALSE)
-                                 tmp[,1] <- out
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
                                  for(j in seq(along = param$.threshold))
                                    {
-                                     tmp[,j + 1] <- as.character(
-                                                                 pamr.predict(
-                                                                              modelFit,
-                                                                              t(newdata),
-                                                                              threshold = param$.threshold[j]))
+                                     tmp[[j+1]] <- as.character(
+                                                                pamr.predict(
+                                                                             modelFit,
+                                                                             t(newdata),
+                                                                             threshold = param$.threshold[j]))
                                    }
                                  out <- tmp
                                }
@@ -274,24 +259,24 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                } else {
                                  out <- predict(modelFit, newdata)
                                }
-
+                             
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)+1),
-                                                   stringsAsFactors = FALSE)
-                                 tmp[,1] <- if(is.matrix(out)) out[,1] else out
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- if(is.matrix(out)) out[,1] else out
+                                 
                                  for(j in seq(along = param$.nprune))
                                    {
                                      prunedFit <- update(modelFit, nprune = param$.nprune[j])
                                      if(modelFit$problemType == "Classification")
                                        {
-                                         tmp[,j+1]  <-  as.character(predict(prunedFit, newdata,  type = "class"))
+                                         tmp[[j+1]]  <-  as.character(predict(prunedFit, newdata,  type = "class"))
                                        } else {
-                                         tmp[,j+1]  <-  predict(prunedFit, newdata)[,1]
+                                         tmp[[j+1]]  <-  predict(prunedFit, newdata)[,1]
                                        }
                                    }
-                                 out <- tmp
+                                 
+                                 out <- if(modelFit$problemType == "Classification") lapply(tmp, as.character) else tmp
                                }
                              out
                            },
@@ -319,23 +304,27 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                            gamboost =, blackboost =, glmboost =
                            {
                              library(mboost)
-                             out <- predict(modelFit, as.matrix(newdata), type = "response")
+                             if(method == "glmboost") newdata <- as.matrix(newdata)
+                             predType <- ifelse(modelFit$problemType == "Classification", "class", "response")
+                             out <- predict(modelFit, newdata, type = predType)
                              if(modelFit$problemType == "Classification") out <- as.character(out)
-
+                             
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)),
-                                                   stringsAsFactors = FALSE)
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- as.vector(out)
                                  
                                  for(j in seq(along = param$.mstop))
                                    {
-                                     tmp[,j]  <- predict(modelFit[param$.mstop[j]], as.matrix(newdata), type = "response")
-                                     if(modelFit$problemType == "Classification") tmp[,j] <- as.character(tmp[,j])
+                                     tmp[[j+1]]  <- as.vector(
+                                                              predict(modelFit[param$.mstop[j]],
+                                                                      newdata,
+                                                                      type = predType))
                                    }
-                                 out <- cbind(out, tmp)
-                                 if(modelFit$problemType == "Classification") out <- coerceChar(out)
+                                 
+                                 out <- if(modelFit$problemType == "Classification") lapply(tmp, as.character) else tmp
                                }
+                             
                              out
                            },
                            
@@ -360,23 +349,19 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                  minMinCrit <- min(param$.mincriterion)
                                  param <- param[param$.mincriterion > minMinCrit,, drop = FALSE]
                                  
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param) + 1),
-                                                   stringsAsFactors = FALSE)
-                                 ## See the examples in ?ctree. For regression, we get a matix and classifiaction
-                                 ## we get a factor vector
-                                 tmp[,1] <- if(is.matrix(out)) out[,1]  else out
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- if(is.matrix(out)) out[,1]  else out
+                                 
                                  for(j in seq(along = param$.mincriterion))
                                    {
                                      tmpPred <- predict(modelFit, newdata, mincriterion = param$.mincriterion[j])
-                                     if(!is.null(modelFit@responses@levels$.outcome)) tmpPred <-as.character(tmpPred)
-                                     tmp[,j + 1] <- if(is.matrix(tmpPred)) tmpPred[,1]  else tmpPred
+                                     tmp[[j+1]] <- if(is.matrix(tmpPred)) tmpPred[,1]  else tmpPred
                                      
                                    }
                                  
-                                 if(!is.null(modelFit@responses@levels$.outcome)) tmp <-  coerceChar(tmp)
-                                 out <- tmp
-                               }
+                                 out <- if(!is.null(modelFit@responses@levels$.outcome)) lapply(tmp, as.character) else tmp
+                               } 
+
                              out
                            },
 
@@ -396,6 +381,7 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                              ## going to assume that all the levels will be passed to
                              ## the output
                              out <- predict(modelFit, newdata, OOB = TRUE)
+                             if(is.matrix(out)) out <- out[,1]
                              if(!is.null(modelFit@responses@levels$.outcome)) out <-as.character(out)
                              
                              out
@@ -405,18 +391,27 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                            {
                              library(elasticnet)
                              out <- predict(modelFit, newdata, s = modelFit$tuneValue$.fraction, mode = "fraction")$fit
-                             
+
                              if(!is.null(param))
                                {
-                                 ## if length(fraction) == 1 then this is a vector, otherwise a matrix
-                                 out2 <- predict(modelFit, newx = as.matrix(newdata), s = param$.fraction, mode = "fraction")$fit
-                                 if(is.vector(out2)) out2 <- as.matrix(out2)
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param) + 1),
-                                                   stringsAsFactors = FALSE)
-                                 tmp[,1] <- out
-                                 for(j in seq(along = param$.fraction)) tmp[,j + 1] <- out2[,j]
-                                 out <- tmp
+                                 if(nrow(param) > 1)
+                                   {
+                                     out <- c(
+                                              list(if(is.matrix(out)) out[,1]  else out),
+                                                 as.list(
+                                                         as.data.frame(
+                                                                       predict(modelFit,
+                                                                               newx = as.matrix(newdata),
+                                                                               s = param$.fraction,
+                                                                               mode = "fraction")$fit)))
+
+                                   } else {
+                                     tmp <- predict(modelFit,
+                                                    newx = as.matrix(newdata),
+                                                    s = param$.fraction,
+                                                    mode = "fraction")$fit
+                                     out <- c(list(if(is.matrix(out)) out[,1]  else out),  list(tmp))
+                                   }
                                }
                              out
                            },
@@ -431,24 +426,22 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                            {
                              library(caTools)
 
-                             out <- caTools::predict.LogitBoost(modelFit, newdata, type="class")
+                             out <- as.character(caTools::predict.LogitBoost(modelFit, newdata, type="class"))
                              
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)),
-                                                   stringsAsFactors = FALSE)
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
                                  
                                  for(j in seq(along = param$.nIter))
                                    {
-                                     tmp[,j] <- as.character(
-                                                             caTools::predict.LogitBoost(
-                                                                                         modelFit,
-                                                                                         newdata,
-                                                                                         nIter = param$.nIter[j]))
+                                     tmp[[j+1]] <- as.character(
+                                                                caTools::predict.LogitBoost(
+                                                                                            modelFit,
+                                                                                            newdata,
+                                                                                            nIter = param$.nIter[j]))
                                    }
-                                 out <- cbind(out, tmp)
-                                 if(modelFit$problemType == "Classification") out <-  coerceChar(out)
+                                 out <- tmp
                                }
                              out
                            },
@@ -472,26 +465,23 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                                     newdata = list(x=t(newdata)),
                                                     n.components = modelFit$tuneValue$.n.components,
                                                     threshold = modelFit$tuneValue$.threshold)$v.pred.1df
-                             
-                             
+                           
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)),
-                                                   stringsAsFactors = FALSE)
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
                                  
-                                 for(j in 1:nrow(param))
+                                 for(j in seq(along = param$.threshold))
                                    {
-                                     tmp[,j] <-  superpc.predict(
-                                                                 modelFit,
-                                                                 modelFit$data,
-                                                                 newdata = list(x=t(newdata)),
-                                                                 threshold = param$.threshold[j],
-                                                                 n.components = param$.n.components[j])$v.pred.1df
+                                     tmp[[j+1]] <- superpc.predict(modelFit,
+                                                                   modelFit$data,
+                                                                   newdata = list(x=t(newdata)),
+                                                                   threshold = param$.threshold[j],
+                                                                   n.components = param$.n.components[j])$v.pred.1df
                                    }
-                                 tmp <- cbind(out, tmp)
-                                 out <- as.data.frame(tmp)
+                                 out <- tmp
                                }
+
                              out
                            },
                            penalized =
@@ -552,8 +542,7 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                              as.character(predict(modelFit, newdata))
                            },
                            glmnet =
-                           {
-                             
+                           {                          
                              library(glmnet)
                              if(!is.matrix(newdata)) newdata <- as.matrix(newdata)
 
@@ -562,15 +551,18 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                  
                                  if(length(modelFit$obsLevels) < 2)
                                    {
-                                     out <- as.data.frame(predict(modelFit, newdata, s = param$.lambda))
+                                     out <- as.list(as.data.frame(predict(modelFit, newdata, s = param$.lambda)))
                                    } else {
                                      tmp <- predict(modelFit, newdata, s = param$.lambda, type = "class")
                                      if(length(modelFit$obsLevels) == 2)
                                        {
                                          tmp <- apply(tmp, 1, function(x, y) y[x], y = modelFit$obsLevels)
-                                         out <- as.data.frame(t(tmp), stringsAsFactors = FALSE)
+                                         out <- as.list(as.data.frame(t(tmp), stringsAsFactors = FALSE))
                                        } else {
-                                         out <- as.data.frame(tmp, stringsAsFactors = FALSE)
+                                         tmp <- predict(modelFit, newdata, s = param$.lambda, type = "class")
+                                         ## When predicting one sample, it downclasses the results to a vector..
+                                         if(nrow(newdata) == 1) tmp <- matrix(tmp, nrow = 1)
+                                         out <- as.list(as.data.frame(tmp, stringsAsFactors = FALSE))
                                        }
                                    }
                                } else {
@@ -593,24 +585,22 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                             as.matrix(newdata),
                                             lambda = modelFit$tuneValue$.lambda,
                                             phi = modelFit$tuneValue$.phi)
-
+                             
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)+1),
-                                                   stringsAsFactors = FALSE)
-                                 tmp[,1] <- out
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
+                                 
                                  for(j in seq(along = param$.lambda))
                                    {
-                                     tmp[,j+1]  <-  predict(modelFit,
-                                                            as.matrix(newdata),
-                                                            lambda = param$.lambda[j],
-                                                            phi = modelFit$tuneValue$.phi)
-                                     
+                                     tmp[[j+1]] <- predict(modelFit,
+                                                           as.matrix(newdata),
+                                                           lambda = param$.lambda[j],
+                                                           phi = modelFit$tuneValue$.phi)
                                    }
                                  out <- tmp
                                }
-
+                             
                              out
                            },
                            lars =
@@ -624,13 +614,12 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
 
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)+1),
-                                                   stringsAsFactors = FALSE)
-                                 tmp[,1] <- out
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
+                                 
                                  for(j in seq(along = param$.fraction))
                                    {
-                                     tmp[,j+1]  <-  predict(modelFit,
+                                     tmp[[j+1]] <- predict(modelFit,
                                                             as.matrix(newdata),
                                                             type = "fit",
                                                             mode = "fraction",
@@ -638,7 +627,6 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                    }
                                  out <- tmp
                                }
-
                              out
                            },
                            lars2 =
@@ -652,13 +640,12 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
 
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)+1),
-                                                   stringsAsFactors = FALSE)
-                                 tmp[,1] <- out
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
+                                 
                                  for(j in seq(along = param$.step))
                                    {
-                                     tmp[,j+1]  <-  predict(modelFit,
+                                     tmp[[j+1]] <- predict(modelFit,
                                                             as.matrix(newdata),
                                                             type = "fit",
                                                             mode = "step",
@@ -666,7 +653,6 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                    }
                                  out <- tmp
                                }
-
                              out
                            },
                            vbmpRadial =
@@ -722,18 +708,17 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                            {
                              library(foba)
                              out <- predict(modelFit, newdata, k = modelFit$tuneValue$.k, type = "fit")$fit
-                             
+
                              if(!is.null(param))
                                {
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)),
-                                                   stringsAsFactors = FALSE)
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
                                  
                                  for(j in seq(along = param$.k))
                                    {
-                                     tmp[,j] <- predict(modelFit, newdata, k = param$.k[j], type = "fit")$fit
+                                     tmp[[j+1]] <- predict(modelFit, newdata, k = param$.k[j], type = "fit")$fit
                                    }
-                                 out <- cbind(out, tmp)
+                                 out <- tmp
                                }
                              out
                            },
@@ -745,15 +730,22 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                              if(!is.null(param))
                                {
                                  tmp <- c(modelFit$tuneValue$.cut.off.growth, param$.cut.off.growth)
+
+                                 ## There are cases where the number of models saved by the function is
+                                 ## less than the values in cut.off.growth (e.g. cut.off.growth = 1:10
+                                 ## but partDSA only has 6 partitions). We will predict the "overage" using
+                                 ## the largest model in the obejct (e.g. models 7:10 predicted by model 6).
                                  if(modelFit$problemType == "Classification")
                                    {
                                      out <- predict(modelFit, newdata)
+                                     if(max(tmp) > ncol(out)) tmp[tmp > ncol(out)] <- ncol(out)
                                      out <- out[tmp]
                                      out <- lapply(out, as.character)
-                                     out <- as.data.frame(do.call("cbind", out), stringsAsFactors = FALSE)
-                                     
                                    } else {
-                                     out <- as.data.frame(predict(modelFit, newdata)[,tmp, drop= FALSE])
+                                     out <- predict(modelFit, newdata)
+                                     if(max(tmp) > ncol(out)) tmp[tmp > ncol(out)] <- ncol(out)
+                                     out <- out[,tmp, drop= FALSE]
+                                     out <- as.list(as.data.frame(out))
                                    }
                                } else {
 
@@ -810,16 +802,14 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                  ## get predictions elegently.
                                  
                                  ## Column order will be (a_1, d_1), (a_1, d_2), ..., (a_p, d_q)
-                                 tmp <- data.frame(
-                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)+1),
-                                                   stringsAsFactors = FALSE)
-                                 tmp[,1] <- out
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
 
                                  ## Using predict.rda, the alpha and delta params will generate all
                                  ## possible combinations, which might not be what the user wanted
                                  ## as specified by tuneGrid. To make sure these match, we will
                                  ## loop over one parameter
-                                 
+                               
                                  uniqueA <- unique(param$.alpha)
                                  index1 <- 2
                                  for(i in 1:length(uniqueA))
@@ -832,11 +822,15 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                                                         xnew = t(as.matrix(newdata)),
                                                         alpha = uniqueA[i],
                                                         delta = delta)
+                                     ## If length(uniqueA) == 1 and length(delta) == 1, tmpPred
+                                     ## gets downcast into a vector (ordinarily a matrix)
+                                     if(is.vector(tmpPred)) tmpPred <- matrix(tmpPred, nrow = 1)
                                      tmpPred <- apply(tmpPred, 2, function(x, y) y[x], y = as.character(modelFit$obsLevels))
-                                     tmp[, index1:index2] <- t(tmpPred)
+                                      if(is.vector(tmpPred)) tmpPred <- matrix(tmpPred, nrow = 1)
+                                     tmp[index1:index2] <- as.list(as.data.frame(t(tmpPred)))
                                      index1 <- index2 + 1
                                    }
-                                 out <- tmp
+                                 out <- lapply(tmp, as.character) 
                                }
 
                              out
